@@ -1,3 +1,4 @@
+import os
 import re
 import sys
 import argparse
@@ -15,22 +16,9 @@ def main_cli():
     parser.add_argument('--no_summary', '-n', action='store_true')
     parser.add_argument('--provider', choices=ir_measures.providers.registry.keys())
     args = parser.parse_args()
+    qrels = _get_qrels(args)
     run = ir_measures.read_trec_run(args.run)
-    qrels = ir_measures.read_trec_qrels(args.qrels)
-    measures, errors = [], []
-    for mstr in args.measures:
-        for m in mstr.split():
-            try:
-                measure = ir_measures.parse_measure(m)
-                if measure not in measures:
-                    measures.append(measure)
-            except ValueError:
-                errors.append(f'syntax error: {m}')
-            except NameError:
-                errors.append(f'unknown measure: {m}')
-    if errors:
-        sys.stderr.write('\n'.join(['error parsing measures'] + errors + ['']))
-        sys.exit(-1)
+    measures = _get_measures(args)
     calc_obj = ir_measures
     if args.provider:
         calc_obj = ir_measures.providers.registry[args.provider]
@@ -50,6 +38,47 @@ def main_cli():
             print(f'{measure}\t{results[measure]:.{args.places}f}')
 
 
+def _get_qrels(args):
+    # gets the qrels, either from a file (priority) or from ir_datasets (if installed)
+    if os.path.exists(args.qrels):
+        return ir_measures.read_trec_qrels(args.qrels)
+    irds_available = False
+    try:
+        import ir_datasets
+        irds_available = True
+    except ImportError:
+        sys.stderr.write(f'Skipping ir_datasets lookup. To use this feature, install ir_datasets.\n')
+    if irds_available:
+        try:
+            ds = ir_datasets.load(args.qrels)
+            if ds.has_qrels():
+                return ds.qrels_iter()
+            sys.stderr.write(f'ir_datasets ID {args.qrels} found but does not provide qrels.\n')
+            sys.exit(-1)
+        except KeyError:
+            sys.stderr.write(f'{args.qrels} not found. (checked file and ir_datasets)\n')
+            sys.exit(-1)
+    sys.stderr.write(f'{args.qrels} not found.\n')
+    sys.exit(-1)
+
+
+def _get_measures(args):
+    measures, errors = [], []
+    for mstr in args.measures:
+        for m in mstr.split():
+            try:
+                measure = ir_measures.parse_measure(m)
+                if measure not in measures:
+                    measures.append(measure)
+            except ValueError:
+                errors.append(f'syntax error: {m}')
+            except NameError:
+                errors.append(f'unknown measure: {m}')
+    if errors:
+        sys.stderr.write('\n'.join(['error parsing measures'] + errors + ['']))
+        sys.exit(-1)
+    return measures
+
 
 if __name__ == '__main__':
     main_cli()
