@@ -9,21 +9,29 @@ def register(measure, aliases=[], name=None):
         registry[alias] = measure
     return registry
 
-from .base import BaseMeasure, ParamInfo, MultiMeasures, MeanAgg, SumAgg
+from .base import Measure, BaseMeasure, ParamInfo, MultiMeasures, MeanAgg, SumAgg
 from .ap import AP, MAP, _AP
+from .bpm import BPM, _BPM
 from .bpref import Bpref, BPref, _Bpref
 from .err import ERR, _ERR
+from .inst import INST, _INST, INSQ, _INSQ
 from .infap import infAP, _infAP
 from .iprec import IPrec, _IPrec
 from .judged import Judged, _Judged
 from .ndcg import nDCG, NDCG, _nDCG
+from .nerr import NERR8, NERR9, NERR10, NERR11, _NERR8, _NERR9, _NERR10, _NERR11
 from .numq import NumQ, _NumQ
 from .numrel import NumRel, _NumRel
 from .numret import NumRet, NumRelRet, _NumRet
-from .p import P, _P
-from .r import R, _R
+from .p import P, Precision, _P
+from .r import R, Recall, _R
 from .rbp import RBP, _RBP
-from .rprec import Rprec, _Rprec
+from .rprec import Rprec, RPrec, _Rprec
 from .rr import RR, MRR, _RR
-from .setp import SetP, _SetP
+from .sdcg import SDCG, _SDCG
+from .set_measures import SetP, SetRelP, _SetP, SetR, _SetR, SetF, _SetF, SetAP, _SetAP
 from .success import Success, _Success
+
+# enable from "ir_measures.measures import *" --- on purpuse, do not include _-prefixed versions,
+# as these are intended for internal use
+__all__ = list(registry.keys())
