@@ -1,8 +1,8 @@
 from ir_measures import measures
-from .base import BaseMeasure, ParamInfo
+from .base import Measure, ParamInfo
 
 
-class _Rprec(measures.BaseMeasure):
+class _Rprec(measures.Measure):
     """
     The precision of at R, where R is the number of relevant documents for a given query. Has the cute property that
     it is also the recall at R.
